﻿using System;
using System.Data.Services;

using ODataService.Simulation;

namespace ODataService
{
    /// <summary>
    ///  Sample OData service exposing runtime data
    ///  as collections of items and subscriptions.
    ///  NOTES:
    ///  1. There are two projects, service and client.  This is the service.
    ///  2. To run the service you need to do one of two things:
    ///     * Run the service in a console with admin privileges (or right-click on it an run as Admin).
    ///     * Give the user running the service (usually the user you are logged in as) a URLACL
    ///       privilege to listen on the endpoint.  This only has to be done once, but requires
    ///       a console with admin privileges.  
    ///       Use an ordinary console if your know the domain\user:
    ///       C:>netsh http add urlacl url=http:/+:10001/ user=[domain]\[user].
    ///       Use a powershell console if you want to full automate:
    ///       netsh http add urlacl http://+:10001/ user=$env:USERDOMAIN\$env:USERNAME
    ///  3. To run the client, no special priveleges are required.  Build and F5 in Visual Studio or double-click.
    /// </summary>
    class Program
    {
        #region Private static fields
        /// <summary>
        /// The OData service host.
        /// </summary>
        private static DataServiceHost odataHost = null;

        /// <summary>
        /// The base URL address for our service.
        /// </summary>
        private static string BaseAddress = "http://localhost:10001/TimeSeriesData.svc";
        #endregion

        #region Program main entry and initialization
        /// <summary>
        /// Program main entry.
        /// Initialize the example, start the service, and wait to end.
        /// </summary>
        /// <param name="args">Command line arguments</param>
        static void Main(string[] args)
        {
            // Load the simulation configuration.
            Persistence.LoadDocument();

            // Create and open an OData service host.
            odataHost = new DataServiceHost(typeof(TimeSeriesDataService), new Uri[] { new Uri(BaseAddress) });
            odataHost.Open();

            // Let the program run until a key is struck.
            Console.ReadKey();

            // Clean up and exit.
            odataHost.Close();
        }
        #endregion
    }

}
