﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace ODataService.Simulation
{
    public class DataSample
    {
        #region Private static fields
        /// <summary>
        /// Auto-generate an always-increasing sample Id.
        /// </summary>
        private static int nextId = 0;
        #endregion

        #region Private fields
        /// <summary>
        /// The sample id.
        /// </summary>
        private int sampleId;

        /// <summary>
        /// The item id that this currently samples.
        /// </summary>
        private int itemId;

        /// <summary>
        /// The current Value of this sample.
        /// </summary>
        private int value;

        /// <summary>
        /// The current Timestamp of this sample.
        /// </summary>
        private DateTime timeStamp;

        /// <summary>
        /// The current Quality of this sample.
        /// </summary>
        private DataQuality quality;
        #endregion

        #region Public properties
        /// <summary>
        /// Gets the Item Id of this sample.
        /// </summary>
        public int Id
        {
            get
            {
                return sampleId;
            }
        }

        /// <summary>
        /// Gets or sets the Item Id of the item this is a sample of.
        /// </summary>
        public int ItemId
        {
            get
            {
                return itemId;
            }
            set
            {
                this.itemId = value;
            }
        }

        /// <summary>
        /// Gets or sets the current Value of this sample.
        /// </summary>
        public int Value
        {
            get
            {
                return value;
            }
            set
            {
                this.value = value;
            }
        }

        /// <summary>
        /// Gets or sets the current Timestamp of this sample.
        /// </summary>
        public DateTime Time
        {
            get
            {
                return timeStamp;
            }
            set
            {
                timeStamp = value;
            }
        }

        /// <summary>
        /// Gets or sets the current Quality of this sample.
        /// </summary>
        public DataQuality Quality
        {
            get
            {
                return quality;
            }
            set
            {
                quality = value;
            }
        }
        #endregion

        #region Constructors
        /// <summary>
        /// Initializes a new instance of the <see cref="DataSample"/> class
        /// Initializing constructor, provides values for the read-only properties.
        /// </summary>
        /// <param name="id">The permanent Id of this sample</param>
        public DataSample(int id)
        {
            this.sampleId = id;

            itemId = 0;
            value = 0;
            timeStamp = DateTime.Now;
            quality = DataQuality.QaulityUncertain;
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="DataSample"/> class.
        /// Auto-generate the next available sample Id, and default the other fields.
        /// </summary>
        public DataSample(DataItem item)
        {
            sampleId = nextId++;

            itemId = item.Id;
            value = item.Value;
            timeStamp = item.Time;
            quality = item.Quality;
        }
        #endregion
    }
}
